/*  ---------------------------------------------------------------------------
    Program  :  Figure10.sas

    Project  :  Regional User Groups Graphics Presentation - 2011
    Authors  :  Watts & Derby

    Purpose  :  This is the code for FIGURE10 from the paper:
                Using SAS GTL to Visualize Your Data when there is Too Much of it to Visualize.

    Purpose  :  Create a multiple-plot display with LAYOUT DATAPANEL to 
                 get a uniform format in each panel.

    Notes    :  This program is distributed on an as-is basis.To run, just change
                GPATH and LIBNAME statements so that they point to a folder on your computer.

                Cumulative #Bookings appears as a label for the Y-axis, because
                 a label is assigned to BOOKINGS in the data step. It appears
                 on the graph with display=ALL in the ROWAXISOPTS statement.
                
    Input    :  Permanent SAS data set: groupedairdata (in ZIP file)
    Output   :  Figure10.png
     ------------------------------------------------------------------------  */

 ods path work.templat(update) sashelp.tmplmst(read);
 ods listing gpath="C:\MySubDir";
 libname AirLines 'C:\MySubDir';
 ods path work.templat(update) sashelp.tmplmst(read);
 
 title1;

  proc template;
     define Style Fig10Style;
      parent = styles.default;
      class GraphFonts /
       'GraphLabelFont' = (", ",8pt) 
       'GraphValueFont' = (", ",8pt);
   /* make gridlines visible in hardcopy - possibly presentation displays*/  
       class graphGridLines/
        contrastColor=CXAAAAAA;
     end;
    run;
    ods listing style=Fig10Style image_dpi=300; 

proc template;
  define statgraph seriesplt;
  dynamic TITLE;
  begingraph / designwidth=450 designheight=450
               borderattrs=(thickness=0px);   /* no border line in this version */
    layout datapanel classvars=(ByDdateLbl) /
      columndatarange=union
      headerlabelattrs=(weight=bold size=8px)
      headerbackgroundcolor=CXBCB9E5
      rowaxisopts=(griddisplay=on display=ALL altdisplay=none
                   displaysecondary=none altdisplaysecondary=(ticks tickvalues)  
                   linearopts=(tickvaluesequence=(start=0 end=180 increment=90)))
      columnaxisopts=(label="Days Before Departure" 
                   REVERSE=TRUE
                   linearopts=(tickvaluesequence=(start=0 end=60 increment=10)));
        layout prototype;
          seriesplot y=bookings x=DaysLeft / group=ddate
                                             lineattrs=(pattern=1 color=black);
        endlayout; /*prototype*/
    endlayout; /*dataPanel */   
  endgraph;
 end;
run;

  ods graphics on / reset imageName="Figure10" antialiasmax=10000 imagefmt=png;
  proc sgrender data=airlines.groupedAirData template=seriesplt;  
  run;
